@@ -41,6 +41,7 @@ from inquirer import prompt, List as iList
 from cmd import Cmd
 
 from pavlovadm.colortext import tabd, error, bgre
+from pavlovadm.__pkginfo__ import version
 
 class PavlovADM(Cmd):
 	servers = {}
@@ -115,9 +116,14 @@ class PavlovADM(Cmd):
 			for l in lines:
 				if not l or not l.startswith('MapRotation'):
 					continue
-				ugcid = l.split('MapId="')[1].split('", ')[0]
-				gmmod = l.split('GameMode="')[1].split('")')[0]
+				ugcid = l.split('MapId')[1].split(',')[0]
+				ugcid = ugcid.strip(' =",')
+				gmmod = l.split('GameMode')[1].split(')')[0]
+				gmmod = gmmod.strip(' ="')
 				name = self._getmapname(ugcid)
+				#print('"%s"'%ugcid)
+				#print('"%s"'%gmmod)
+				#print('"%s"'%name)
 				self.maps[name] = [ugcid, gmmod]
 				self.mapnames[ugcid] = name
 			with open(expanduser(self.maptbl), 'w+') as mfh:
@@ -149,7 +155,7 @@ class PavlovADM(Cmd):
 			return '%s %s'%(self.maps[mapp][0], mode)
 
 	def _getitem(self):
-		with open(self.itemtbl, 'r') as ifh:
+		with open(expanduser(self.itemtbl), 'r') as ifh:
 			items = [l.split(',')[0] for l in ifh.readlines()]
 		ask = [
             iList(
@@ -221,8 +227,6 @@ class PavlovADM(Cmd):
 		others = ['SwitchMap', 'SwitchTeam', 'GiveItem', 'GiveCash', 'GiveTeamCash', 'SetPlayerSkin', 'SetLimitedAmmoType']
 		order = ['Info', 'SwitchMap', 'RotateMap', 'ResetSND', 'Kick', 'Ban', 'Unban', 'InspectPlayer', 'GiveItem', 'GiveCash', 'GiveTeamCash', 'SetPlayerSkin', 'SetLimitedAmmoType', 'RefreshList', 'ServerInfo', '<Disconnect>']
 		hlp = self.hlp if self.hlp else self.rconexec(srv, 'Help')
-		if not hlp:
-			error('no help', hlp)
 		hlp = hlp['Help']
 		hlp = [h.split(' ')[0] for h in hlp.split(', ') if h.split(' ')[0]] + ['Info']
 		ask = [
@@ -280,6 +284,8 @@ class PavlovADM(Cmd):
 
 	def _getsteamid(self, srv, cmd):
 		userids = self._players(srv)
+		if self.dbg:
+			print(bgre(userids))
 		if not userids:
 			print('\nerror: executing "%s" is impossible - no players\n'%cmd)
 			return
@@ -288,7 +294,7 @@ class PavlovADM(Cmd):
                 'user',
                 carousel=True,
                 message='select user to %s'%cmd,
-                choices=list(userids.keys()) + ['<Return>'],
+                choices=list(userids) + ['<Return>'],
             ),
         ]
 		usr = list(prompt(ask).values())[0]
@@ -299,7 +305,10 @@ class PavlovADM(Cmd):
 
 	def _players(self, srv):
 		pout = dict(self.rconexec(srv, 'RefreshList'))['PlayerList']
-		return pout
+		players = {}
+		for p in pout:
+			players[p['Username']] = p['UniqueId']
+		return players
 		#pout = pout.split('{\n\t"PlayerList": [')[1]
 		#pout = pout.split('\t]\n}')[0]
 		##print(pout)
@@ -412,11 +421,10 @@ def main():
 				with open(expanduser(f), 'r') as lfh, open('%s/%s'%(cfgdir, basename(f)), 'w+') as gfh:
 					gfh.write(lfh.read())
 	cfgs = config('%s/%s.conf'%(cfgdir, __me))
-
 	pars = ArgumentParser(description=__dsc)
 	pars.add_argument(
         '--version',
-        action='version', version='%s v0.13'%__me)
+        action='version', version='%s v%s'%(__me, version))
 	pars.add_argument(
         '-D', '--debug',
         dest='dbg', action='store_true', help='enable debugging')
